---
title: <span class="badge object-type-scalar"></span> GigahertzRotation
---
# <span class="badge object-type-scalar"></span> GigahertzRotation

Rotational Speed: Gigahertz (GHz)

## Definition

```python
# Rotational Speed: Gigahertz (GHz)
GigahertzRotation: typing.Literal["rotghz"] = "rotghz"
```
